package com.ruoyi.ss.dividendRefund.mapper;

import com.ruoyi.ss.dividendRefund.domain.DividendRefund;
import com.ruoyi.ss.dividendRefund.domain.DividendRefundQuery;
import com.ruoyi.ss.dividendRefund.domain.DividendRefundVO;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 分成退款记录Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-25
 */
public interface DividendRefundMapper
{
    /**
     * 查询分成退款记录
     *
     * @param id 分成退款记录主键
     * @return 分成退款记录
     */
    DividendRefundVO selectDividendRefundById(Long id);

    /**
     * 查询分成退款记录列表
     *
     * @param query 分成退款记录
     * @return 分成退款记录集合
     */
    List<DividendRefundVO> selectDividendRefundList(@Param("query")DividendRefundQuery query);

    /**
     * 新增分成退款记录
     *
     * @param dividendRefund 分成退款记录
     * @return 结果
     */
    int insertDividendRefund(DividendRefund dividendRefund);

    /**
     * 批量新增分成退款记录
     */
    int batchInsert(@Param("list") List<? extends DividendRefund> list);

    /**
     * 批量修改分成退款记录
     */
    int batchUpdate(@Param("list") List<? extends DividendRefund> list);

    /**
     * 修改分成退款记录
     *
     * @param dividendRefund 分成退款记录
     * @return 结果
     */
    public int updateDividendRefund(@Param("data") DividendRefund dividendRefund);

    /**
     * 删除分成退款记录
     *
     * @param id 分成退款记录主键
     * @return 结果
     */
    int deleteDividendRefundById(Long id);

    /**
     * 批量删除分成退款记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDividendRefundByIds(Long[] ids);

    /**
     * 查询分成退款金额
     *
     * @param query 分成退款记录查询条件
     * @return 分成退款金额
     */
    BigDecimal selectSumOfAmount(@Param("query") DividendRefundQuery query);
}
